
import React, { useEffect, useState, useRef } from 'react';
import { Modal, Form, Select, Alert, Input } from '@arco-design/web-react';
import { Col, Space, Button, Tooltip, Empty, Row } from 'antd';
import * as $$ from '@/utils/utility';
import { Scrollbars } from "react-custom-scrollbars";
import { agree, empty } from "../../../../assets/images";
import { IconLocation } from '@arco-design/web-react/icon';
import DetailDialog from "../../../../components/personCard/DetailDialog";
const appUrl = $$.appUrl;


const FormItem = Form.Item;
const TextArea = Input.TextArea;

function listRepeatCaseApi(data) {
  return $$.ax.request({ url: `caseRepeatInfo/listRepeatCase`, type: 'get', service: 'mediate', data });
}




const RepeatView = ({ caseId }) => {
  const formRef = useRef();
  const user = $$.getSessionStorage('customerSystemUser') || {};
  const [hisData, setHisData] = useState([]);
  const [detailVisabled, setDetailVisabled] = useState(false);
  const [modalData, setModalData] = useState({});
  function handleCheckPreview(params) {
    setModalData(params)
    setDetailVisabled(true)
  }

  function selectChange(params) {

  }

  async function listRepeatCase(id) {
    global.setSpinning(true);
    const res = await listRepeatCaseApi({ caseId: id });
    global.setSpinning(false);
    if (res.type) {
      let data = res.data;
      setHisData(data || [])
    }
  }


  useEffect(() => {
    listRepeatCase(caseId);
  }, [])

  return (
    <div>
      {
        hisData?.length === 0 ?
          <div className='handle-content-empty' style={{ marginTop: '10%' }}>
            {$$.MyNewEmpty()}
          </div> :
          <div style={{ padding: '12px 16px' }}>
            <div style={{ padding: '4px 0 12px' }}><Alert type='info' content={<span>以下重复事项已合并至当前事项内</span>} /></div>
            {
              hisData?.map((item, index) => (
                <div key={`RepeatView${index}`}>
                  <Space size='small'>
                    <div className='MediationInfo-subTitle' style={{ marginTop: '-7px' }}></div><h5>疑似重复事项{index + 1}</h5>
                  </Space>
                  <table border="1" align="center" cellpadding="6" className="table">
                    <tr>
                      <th bgcolor="#F7F8FA" className="table-title" width="120" >事项编号</th>
                      <td >{item?.caseRef ? <span onClick={() => { window.open(`${$$.windowUrl}/windowDetail?caseTaskId=${item.caseId}&caseId=${item.caseId}`) }} className='public-color public-a'>{item.caseRef}</span> : "-"}</td>
                      <th bgcolor="#F7F8FA" className="table-title" width="120">事项状态</th>
                      <td >{item?.mergeResult === 1 ? "主体案件-"+item.statusName : "重复案件-已挂起"}</td>
                    </tr>
                    <tr>
                      <th bgcolor="#F7F8FA" className="table-title" width="120" >事项来源</th>
                      <td>{item?.caseSource || '-'}</td>
                      <th bgcolor="#F7F8FA" className="table-title" width="120">数据来源</th>
                      {/* <td >{item?.dataSource || '-'}</td> */}
                      <td>{'本系统'}</td>
                    </tr>
                    <tr>
                      <th bgcolor="#F7F8FA" className="table-title">申请方</th>
                      <td><div style={{ display: 'flex', gap: '8px' }}>{item?.plaintiffList?.map(i => (<span style={{ textDecoration: 'underline' }} onClick={() => { handleCheckPreview(i) }} className='public-color public-a'>{i.trueName || '-'}{`（${i.certiNo || '-'}）`}</span>)) || '-'}</div></td>
                      <th bgcolor="#F7F8FA" className="table-title">被申请方</th>
                      <td><div style={{ display: 'flex', gap: '8px' }}>{item?.defendantList?.map(i => (<span style={{ textDecoration: 'underline' }} onClick={() => { handleCheckPreview(i) }} className='public-color public-a'>{i.trueName || '-'}{`（${i.certiNo || '-'}）`}</span>)) || '-'}</div></td>
                    </tr>
                    <tr>
                      <th bgcolor="#F7F8FA" className="table-title">问题属地</th>
                      <td><div style={{ display: 'flex', alignItems: 'center', gap: '8px' }}><IconLocation />{item?.queProvName || ''}&nbsp;{item?.queCityName || ''}&nbsp;{item?.queAreaName || ''}&nbsp;{item?.queRoadName || '-'}</div></td>
                      <th bgcolor="#F7F8FA" className="table-title">纠纷发生地</th>
                      <td>{item?.addr || '-'}</td>
                    </tr>
                    <tr>
                      <th bgcolor="#F7F8FA" className="table-title">登记机构</th>
                      <td>{item?.inputUnitName || '-'}</td>
                      <th bgcolor="#F7F8FA" className="table-title">登记时间</th>
                      <td>{item?.inputTime || '-'}</td>
                    </tr>
                    <tr>
                      <th bgcolor="#F7F8FA" className="table-title">承办部门</th>
                      <td>{item?.mediateUnitName || '-'}</td>
                      <th bgcolor="#F7F8FA" className="table-title">受理时间</th>
                      <td>{item?.acceptTime || '-'}</td>
                    </tr>
                    <tr>
                      <th bgcolor="#F7F8FA" className="table-title">经办人</th>
                      <td>{item?.mediator || '-'}</td>
                      <th bgcolor="#F7F8FA" className="table-title">配合部门</th>
                      <td>{item?.assistUnitName || '-'}</td>
                    </tr>
                    <tr>
                      <th bgcolor="#F7F8FA" className="table-title">事项概况</th>
                      <td colspan="3">{item?.caseDes || '-'}</td>
                    </tr>
                    <tr>
                      <th bgcolor="#F7F8FA" className="table-title">事项申请</th>
                      <td colspan="3">{item?.caseClaim || '-'}</td>
                    </tr>
                  </table>
                </div>
              ))
            }
          </div>
      }
      <Modal
        title={'查看' + modalData.trueName}
        visible={detailVisabled}
        onOk={() => setDetailVisabled(false)}
        onCancel={() => {
          setDetailVisabled(false)
        }}
        wrapStyle={{ zIndex: '1006' }}
        autoFocus={false}
        focusLock={true}
        footer={null}
        unmountOnExit={true}
        maskClosable={false}
      >
        <DetailDialog editData={modalData} personData={modalData} />
      </Modal>
    </div>
  )
}

export default RepeatView;

